<?php
/**
 * Define fille.

 * @package WOOCP
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // restict for direct access.
}

if ( ! class_exists( 'Admin_Ka_Add_Recaptcha' ) ) {

	/**
	 * Class start.

	 * @package WOOCP
	 */
	class Admin_Ka_Add_Recaptcha extends Main_Ka_Add_Recaptcha {

		/**
		 * Function construct start.
		 */
		public function __construct() {

			add_action( 'admin_menu', array( $this, 'add_recaptcha_menu' ) );
			add_action( 'admin_init', array( $this, 'ka_add_register_fields' ) );
			add_action( 'all_admin_notices', array( $this, 'ka_recaptcha_render_tabs' ), 5 );
			add_action( 'admin_enqueue_scripts', array( $this, 'gr_enque_js_call_back' ) );
		}

		public function gr_enque_js_call_back() {
			wp_enqueue_script( 'select2_js', plugins_url( 'Assets/js/select2.js', __FILE__ ), true, '1.0', $in_footer = false );
			wp_enqueue_style( 'select2_css', plugins_url( 'Assets/css/select2.css', __FILE__ ), false, '1.0' );
			wp_enqueue_script( 'gr_search_user_role', plugins_url( 'Assets/js/gr-user-role.js', __FILE__ ), true, '1.0', $in_footer = false );
		}

		/**
		 * Function construct start.
		 */
		public function add_recaptcha_menu() {
			add_menu_page(
				'reCaptcha', // Page title.
				esc_html__( 'reCaptcha', 'recaptcha_verification' ), // Title.
				'manage_options', // Capability.
				'ka_captcha', // slug.
				array( $this, 'create_recaptcha_setting_page' ),
				plugins_url( 'Assets/img/logo.png', __FILE__ ),
				55
			); // Callback.

		}

		public function get_current_tab() {
			$screen = get_current_screen();

			$tabs_screens = array(
				'toplevel_page_ka_captcha',
			);

			switch ( $screen->id ) {
				case 'toplevel_page_ka_captcha':
					return 'general';

			}
		}

		public function get_tab_screen_ids() {
			$tabs_screens = array(
				'toplevel_page_ka_captcha',
			);

			return $tabs_screens;
		}
		public function ka_recaptcha_render_tabs() {

			global $post, $typenow;
			$screen = get_current_screen();
			// handle tabs on the relevant WooCommerce pages
			if ( $screen && in_array( $screen->id, $this->get_tab_screen_ids(), true ) ) {

				$tabs = array(
					'captcha_general_setting' => array(
						'title' => __( 'General Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha' ),
					),

					'wcrecaptcha'             => array(
						'title' => __( 'WC Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha&tab=wcrecaptcha&subtab_recaptcha=registration_tab' ),
					),
					'wprecaptcha'             => array(
						'title' => __( 'WP Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha&tab=wprecaptcha&subtab_wprecaptcha=wpregistration_tab' ),
					),
				);

				if ( ! is_multisite() && ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
					unset( $tabs['wcrecaptcha'] );
				}

				$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : 'captcha_general_setting';

				if ( is_array( $tabs ) ) { ?>
					
					<div class="wrap woocommerce">
						<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">
							<?php
							$current_tab = $this->get_current_tab() == 'general' ? $active_tab : $this->get_current_tab();

							foreach ( $tabs as $id => $tab_data ) {
								$class = $id === $current_tab ? array( 'nav-tab', 'nav-tab-active' ) : array( 'nav-tab' );
								printf( '<a href="%1$s" class="%2$s">%3$s</a>', esc_url( $tab_data['url'] ), implode( ' ', array_map( 'sanitize_html_class', $class ) ), esc_html( $tab_data['title'] ) );
							}
							?>
						</h2>
					</div>
					<?php
				}
			}
		}

		/**
		 * Function construct start.
		 */
		public function create_recaptcha_setting_page() {
			global $active_tab;
			if ( isset( $_GET['tab'] ) ) {
				$active_tab = sanitize_text_field( wp_unslash( $_GET['tab'] ) );
			} else {
				$active_tab = 'captcha_general_setting';
			}
			if ( isset( $_GET['subtab_recaptcha'] ) ) {
				$active_tab_recaptcha = sanitize_text_field( $_GET['subtab_recaptcha'] );
			} else {
				$active_tab_recaptcha = 'registration_tab';
			}

			if ( isset( $_GET['subtab_wprecaptcha'] ) ) {
				$active_tab_wprecaptcha = sanitize_text_field( $_GET['subtab_wprecaptcha'] );
			} else {
				$active_tab_wprecaptcha = 'wpregistration_tab';
			}

			?>
			<div class="af-rfq-settings">
				<!-- Title above Tabs -->
				<h2> 
					<?php
					echo esc_html__( 'Recaptcha Setting', 'recaptcha_verification' );
					?>
				</h2>
				<?php settings_errors(); ?>

				<form method="POST" action="options.php" >

					<?php

					if ( 'captcha_general_setting' === $active_tab ) {

						settings_fields( 'wp_captcha_general' );
						do_settings_sections( 'wp_recaptcha_general' );

					}

					if ( 'wcrecaptcha' == $active_tab ) {

						$tabs_arr = array(
							'registration_tab'   => 'WC Registration',
							'login_tab'          => 'WC Login',
							'lost_password_tab'  => 'WC Lost Password',
							'checkout_tab'       => 'WC Checkout',
							'payment_tab'        => 'WC Payment Method',
							'payorder_tab'       => 'WC Pay for order',
							'product_review_tab' => 'WC Product Review',
						);

						?>
						<ul class="subsubsub">
							<?php foreach ( $tabs_arr as $key => $lable ) : ?>

								<li>

									<a href="?page=ka_captcha&tab=wcrecaptcha&subtab_recaptcha=<?php echo esc_attr( $key ); ?>" class="<?php echo esc_attr( $active_tab_recaptcha == $key ? 'current' : '' ); ?>"><?php echo esc_html__( $lable, 'recaptcha_verification' ); ?></a>

									<?php
									if ( end( $tabs_arr ) !== $lable ) {
										echo esc_html__( ' | ', 'recaptcha_verification' );
									}
									?>
								</li>

							<?php endforeach ?>

						</ul>

						<?php

						$fields_registration = array(
							'registration_tab'   => array( 'captcha-woo-regs', 'recaptcha-woo-regs' ),
							'login_tab'          => array( 'captcha-woo-login', 'recaptcha-woo-login' ),
							'lost_password_tab'  => array( 'captcha-woo-lpass', 'recaptcha-woo-lpass' ),
							'checkout_tab'       => array( 'captcha-woo-guest-checkout', 'recaptcha-woo-guest-checkout' ),
							'payment_tab'        => array( 'captcha-p_method-settings', 'recaptcha-p_method-settings' ),
							'payorder_tab'       => array( 'captcha-p-order-settings', 'recaptcha-p-order-settings' ),
							'product_review_tab' => array( 'captcha-product-review-settings', 'recaptcha-product-review-settings' ),

						);

						foreach ( $fields_registration as $key => $reg_and_sec_arr ) {
							if ( $key === $active_tab_recaptcha ) {

								settings_fields( current( $reg_and_sec_arr ) );
								do_settings_sections( end( $reg_and_sec_arr ) );

							}
						}
					}

					if ( 'wprecaptcha' == $active_tab ) {

						$tabs_wparr = array(
							'wpregistration_tab'  => 'WP Registration',
							'wplogin_tab'         => 'WP Login',
							'wplost_password_tab' => 'WP Lost Password',
							'wp_coment_meta_tab'  => 'WP Comment',
						);
						?>

						<ul class="subsubsub">
							<?php foreach ( $tabs_wparr as $key => $wplable ) : ?>
								<li>

									<a href="?page=ka_captcha&tab=wprecaptcha&subtab_wprecaptcha=<?php echo esc_attr( $key ); ?>" class="<?php echo esc_attr( $active_tab_wprecaptcha == $key ? 'current' : '' ); ?>"><?php echo esc_html__( $wplable, 'recaptcha_verification' ); ?></a>

									<?php
									if ( end( $tabs_wparr ) != $wplable ) {
										echo esc_html__( ' | ', 'recaptcha_verification' );
									}
									?>
								</li>

							<?php endforeach ?>

						</ul>

						<?php

						$wpfields_registration = array(
							'wpregistration_tab'  => array( 'wp_captcha_registration', 'wp_recaptcha_registration' ),
							'wplogin_tab'         => array( 'wp_captcha_login', 'wp_recaptcha_login' ),
							'wplost_password_tab' => array( 'wp_captcha_lostpassword', 'wp_recaptcha_lostpassword' ),
							'wp_coment_meta_tab'  => array( 'wp_captcha_coment_meta', 'wp_recaptcha_coment_meta' ),

						);

						foreach ( $wpfields_registration as $key => $wpreg_and_sec_arr ) {
							if ( $key === $active_tab_wprecaptcha ) {

								settings_fields( current( $wpreg_and_sec_arr ) );
								do_settings_sections( end( $wpreg_and_sec_arr ) );

							}
						}
					}

					?>
					<?php submit_button(); ?>
				</form>
			</div>	
			<?php
		}
		// WordPress back-end.


		/**
		 * Function construct start.
		 */
		public function ka_add_register_fields() {

			include KA_PLUGIN_DIR . '/inc/settings/general-settings-bckend.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-registration-page-settings.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-product-review-settings.php';

			include KA_PLUGIN_DIR . '/inc/settings/woo-login-page-settings.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-lost-password-setting-captcha.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-checkout-page.php';
			include KA_PLUGIN_DIR . '/inc/settings/wp-login-captcha-setting.php';
			include KA_PLUGIN_DIR . '/inc/settings/wp-registration-captcha-setting.php';
			include KA_PLUGIN_DIR . '/inc/settings/wp-comment-captcha-setting.php';
			include KA_PLUGIN_DIR . '/inc/settings/wp-lost-password-page-captcha-settings.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-payment-method-captcha-settings.php';
			include KA_PLUGIN_DIR . '/inc/settings/woo-pay-for-order-captcha.php';
		}
	}

	new Admin_Ka_Add_Recaptcha();
}


