<?php
/**
 * Plugin Name:       Google reCaptcha for WooCommerce
 * Plugin URI:        https://woocommerce.com/products/koala-google-recaptcha-for-woocommerce
 * Description:       Add reCaptcha to your WooCommerce and WordPress login, registration, reset password and other pages.
 * Version:           1.1.0
 * Author:            KoalaApps
 * Developed By:      KoalaApps
 * Author URI:        https://woocommerce.com/vendor/koalaapps/
 * Support:           https://woocommerce.com/vendor/koalaapps/
 * Domain Path:       /languages
 * TextDomain :       recaptcha_verification
 * WC requires at least: 3.0.9
 * WC tested up to: 7.*.*
 * Woo: 7673745:724159e27ebb90c2e770cafffa65ec6a
/**
 * Define class.
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Class start.
 */

class Main_Ka_Add_Recaptcha {
	/**
	 * Function construct start.
	 */
	public function __construct() {
		/**
		 *Define Global Constants.
		 */
		$this->apbgp_global_constents_vars();
		/**
		 *Load Text Domain.
		 */
		add_action( 'wp_loaded', array( $this, 'accm_init' ) );

		/**
		 *Include other Files.
		 */
		if ( is_admin() ) {
			/**
			 *Include Admin Class.
			 */
			include_once KA_PLUGIN_DIR . 'class-admin-ka-add-recaptcha.php';
		} else {
			/**
			 *Include front clas.
			 */
			include_once KA_PLUGIN_DIR . 'class-frontend-ka-add-recaptcha.php';
		}
		add_action( 'wp_ajax_validation_captchav3', array( $this, 'validation_captchav3' ) );
		add_action( 'wp_ajax_nopriv_validation_captchav3', array( $this, 'validation_captchav3' ) );

		//HOPS compatibility
		add_action('before_woocommerce_init', array($this, 'kagrc_HOPS_Compatibility')); 
	}

	public function kagrc_HOPS_Compatibility() {

		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}


	/**
	 * Function start.
	 */
	public function apbgp_global_constents_vars() {
		if ( ! defined( 'KA_URL' ) ) {
			define( 'KA_URL', plugin_dir_url( __FILE__ ) );
		}
		if ( ! defined( 'KA_BASENAME' ) ) {
			define( 'KA_BASENAME', plugin_basename( __FILE__ ) );
		}
		if ( ! defined( 'KA_PLUGIN_DIR' ) ) {
			define( 'KA_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
	}
	/**
	 * Function accm init start.
	 */
	public function accm_init() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
			load_plugin_textdomain( 'recaptcha_verification', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}
	}

	public function validation_captchav3() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( $_POST['nonce'] ) : '';
		if ( ! wp_verify_nonce( $nonce, 'recaptcha-ajax-nonce' ) ) {
			die( 'Failed ajax security check!' );
		}

		if ( isset( $_POST['captcha_token'] ) ) {

			$captcha_token      = isset( $_POST['captcha_token'] ) ? sanitize_text_field( $_POST['captcha_token'] ) : '';
			$recaptcha_url      = 'https://www.google.com/recaptcha/api/siteverify';
			$recaptcha_secret   = get_option( 'add_captcha_secret_key_field' ); // Insert your secret key here
			$recaptcha_response = $captcha_token;
			$recaptcha          = wp_remote_get( 'https://www.google.com/recaptcha/api/siteverify?secret=' . $recaptcha_secret . '&response=' . $captcha_token );

			if ( is_array( $recaptcha ) && ! is_wp_error( $recaptcha ) ) {
				$response_body = wp_remote_retrieve_body( $recaptcha ); // Retrieve the response body

				$recaptcha_data           = json_decode( $response_body ); // Decode the response body
				$captcha_custom_score_opt = get_option( 'captcha_custom_score_opt' ) ? get_option( 'captcha_custom_score_opt' ) : 0;

				if ( $recaptcha_data->success && $recaptcha_data->score >= $captcha_custom_score_opt ) {
					wp_send_json( array( 'success' => true ) );
					wp_die();
				}
			}
		}
		wp_send_json( array( 'success' => false ) );
		wp_die();
	}
}
if ( class_exists( 'Main_Ka_Add_Recaptcha' ) ) {
	new Main_Ka_Add_Recaptcha();
}
