<?php

/**
 * Define fille.
 *
 * @package WOOCP
 */
if ( ! defined( 'ABSPATH' ) ) {
	die;
}
add_settings_section(
	'tab_1_section',         // ID used to identify this section and with which to register options.
	'',                  // Title to be displayed on the administration page.
	'tab_1_section_callback', // Callback used to render the description of the section.
	'wp_recaptcha_general'                           // Page on which to add this section of options.
);

add_settings_field(
	'captcha_type_option', // ID used to identify the field throughout the theme.
	esc_html__( 'Recaptcha Version', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'set_recaptcha_version',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'captcha_type_option'
);

add_settings_field(
	'captcha_general_title_option', // ID used to identify the field throughout the theme.
	esc_html__( 'Recaptcha Field Title', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'captcha_general_title_clbck',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'captcha_general_title_option'
);

add_settings_field(
	'add_captcha_site_key_field', // ID used to identify the field throughout the theme.
	esc_html__( 'Site Key', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'captcha_fields_callback',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'add_captcha_site_key_field'
);
add_settings_field(
	'add_captcha_secret_key_field', // ID used to identify the field throughout the theme.
	esc_html__( 'Secret Key', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'captcha_fields_callback_1',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'add_captcha_secret_key_field'
);
if ( ! is_multisite() && in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {

	add_settings_field(
		'captcha_country_select_opt', // ID used to identify the field throughout the theme.
		esc_html__( 'Exclude Countries', 'recaptcha_verification' ), // The label to the left of the option interface element.
		'recaptcha_country_select_clbck',   // The name of the function responsible for rendering.
		'wp_recaptcha_general', // The page on which this option will be displayed.
		'tab_1_section'// The name of the section to which this field belongs.
	);
	register_setting(
		'wp_captcha_general',
		'captcha_country_select_opt'
	);
}

add_settings_field(
	'captcha_ip_range_opt', // ID used to identify the field throughout the theme.
	esc_html__( 'IP Range', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'captcha_ip_range_callback',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'captcha_ip_range_opt'
);

add_settings_field(
	'captcha_custom_score_opt', // ID used to identify the field throughout the theme.
	esc_html__( 'ReCaptcha Score', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'captcha_custom_score_callback',   // The name of the function responsible for rendering.
	'wp_recaptcha_general', // The page on which this option will be displayed.
	'tab_1_section'// The name of the section to which this field belongs.
);
register_setting(
	'wp_captcha_general',
	'captcha_custom_score_opt'
);


if ( ! function_exists( 'recaptcha_country_select_clbck' ) ) {
	function recaptcha_country_select_clbck() {
		$country_select = get_option( 'captcha_country_select_opt' );
		$countries      = WC()->countries->get_shipping_countries();

		asort( $countries );

		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( 'Disable reCAPTCHA for specific countries. ', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<select class="wc-enhanced-select captcha_country_select_opt"  id="captcha_country_select_opt" multiple="multiple" name="captcha_country_select_opt[]">
			<?php
			if ( ! empty( $countries ) ) {
				foreach ( $countries as $key => $val ) {
					?>
					<option value="<?php echo esc_attr( $key ); ?>" 
						<?php
						if ( in_array( $key, (array) $country_select ) ) {
							echo 'selected="selected"';
						}
						?>
						>
						<?php echo esc_html__( $val, 'recaptcha_verification' ); ?>
					</option>
					<?php
				}
			}
			?>
		</select>

		<?php
	}
}

if ( ! function_exists( 'captcha_general_title_clbck' ) ) {
	function captcha_general_title_clbck() {
		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( 'Field text for Recaptcha. ', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<input type="text" name="captcha_general_title_option"  value="<?php echo esc_attr( get_option( 'captcha_general_title_option' ) ); ?>">
		<?php
	}
}
if ( ! function_exists( 'captcha_ip_range_callback' ) ) {
	function captcha_ip_range_callback() {
		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( 'Disable reCaptcha for IP/Range', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<input type="text" name="captcha_ip_range_opt"  value="<?php echo esc_attr( get_option( 'captcha_ip_range_opt' ) ); ?>">
		<?php
	}
}

if ( ! function_exists( 'captcha_custom_score_callback' ) ) {
	function captcha_custom_score_callback() {
		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( 'Customize ReCaptcha Score.score range is 0.1 to 0.9', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<input type="number" min="0.1" max="0.9" step=".1" name="captcha_custom_score_opt"  value="<?php echo esc_attr( get_option( 'captcha_custom_score_opt' ) ); ?>">


		<?php
	}
}

if ( ! function_exists( 'set_recaptcha_version' ) ) {
	function set_recaptcha_version() {
		?>
		<input type="radio" name="captcha_type_option" value="1" <?php checked( get_option( 'captcha_type_option' ), '1' ); ?> checked >
		<label for="v2"><?php echo esc_html__( 'V2', 'recaptcha_verification' ); ?></label>


		<br><br>
		<input type="radio" name="captcha_type_option" value="0" <?php checked( get_option( 'captcha_type_option' ), '0' ); ?>   >
		<label for="V3"><?php echo esc_html__( 'V3', 'recaptcha_verification' ); ?></label>

		<?php
	}
}
if ( ! function_exists( 'captcha_fields_callback' ) ) {
	function captcha_fields_callback() {
		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( '  Add site key for Recaptcha API ', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<input type="text" name="add_captcha_site_key_field"  value="<?php echo esc_attr( get_option( 'add_captcha_site_key_field' ) ); ?>"><p style="margin-left: 20px;"><?php echo esc_html__( 'Get site key for reCaptcha from ', 'recaptcha_verification' ); ?><a href="https://www.google.com/recaptcha/admin/create" target="_blank">here</a></p>
		<?php
	}
}

if ( ! function_exists( 'captcha_fields_callback_1' ) ) {
	function captcha_fields_callback_1() {
		?>
		<span class="ka-gr-tooltip" data-tooltip="<?php echo esc_html__( 'Add secret key for Recaptcha API', 'recaptcha_verification' ); ?>"><span class="ka-gr-tooltip-trigger">?</span></span>
		<input type="text" value="<?php echo esc_attr( get_option( 'add_captcha_secret_key_field' ) ); ?>" name="add_captcha_secret_key_field"  value="<?php echo esc_attr( get_option( 'add_captcha_secret_key_field' ) ); ?>"><p  style="margin-left: 20px;"><?php echo esc_html__( 'Get secret key for reCaptcha from ', 'recaptcha_verification' ); ?><a href="https://www.google.com/recaptcha/admin/create" target="_blank">here</a></p>
		<?php
	}
}

if ( ! function_exists( 'tab_1_section_callback' ) ) {
	function tab_1_section_callback() {
	}
}
